precision highp float;
varying highp vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture1;//black line
uniform sampler2D inputImageTexture2;//yellow line
uniform float offset;
uniform float ratio;// w/h

vec4 hardlightBlend(vec4 base, vec4 overlay) {
    overlay = overlay * base.a;
    float ra;
    if (2.0 * overlay.r < overlay.a) {
        ra = 2.0 * overlay.r * base.r + overlay.r * (1.0 - base.a) + base.r * (1.0 - overlay.a);
    } else {
        ra = overlay.a * base.a - 2.0 * (base.a - base.r) * (overlay.a - overlay.r) + overlay.r * (1.0 - base.a) + base.r * (1.0 - overlay.a);
    }

    float ga;
    if (2.0 * overlay.g < overlay.a) {
        ga = 2.0 * overlay.g * base.g + overlay.g * (1.0 - base.a) + base.g * (1.0 - overlay.a);
    } else {
        ga = overlay.a * base.a - 2.0 * (base.a - base.g) * (overlay.a - overlay.g) + overlay.g * (1.0 - base.a) + base.g * (1.0 - overlay.a);
    }

    float ba;
    if (2.0 * overlay.b < overlay.a) {
        ba = 2.0 * overlay.b * base.b + overlay.b * (1.0 - base.a) + base.b * (1.0 - overlay.a);
    } else {
        ba = overlay.a * base.a - 2.0 * (base.a - base.b) * (overlay.a - overlay.b) + overlay.b * (1.0 - base.a) + base.b * (1.0 - overlay.a);
    }
    return vec4(ra, ga, ba, base.a);
}

void main()
{
    vec2 uv = textureCoordinate;
    float padding = offset;
    if(ratio >= 1.0) {
        uv.x += padding;//6% + 2%
        if(uv.x > 1.02) {
            uv.x -= 1.02;
            vec4 srcColor = texture2D(inputImageTexture, uv);
            if(uv.x < 0.02) {
                vec2 blackLineUv = vec2(uv.x / 0.02 * 0.35 + 0.65, uv.y);
                vec4 blackLineColor = texture2D(inputImageTexture1, blackLineUv);
                srcColor = mix(srcColor, blackLineColor, blackLineColor.a);
                if(uv.x < 0.02) {
                    vec2 yellowLineUv = vec2(uv.x / 0.02, uv.y);
                    vec4 yellowLineColor = texture2D(inputImageTexture2, yellowLineUv);
                    srcColor = hardlightBlend(srcColor,yellowLineColor);
                }
            } 
            gl_FragColor = srcColor;
        } else if(uv.x <= 1.0) {
            if(uv.x > 0.98) {
                vec2 blackLineUv = vec2((uv.x - 0.98) / 0.02 * 0.35, uv.y);
                vec4 blackLineColor = texture2D(inputImageTexture1, blackLineUv);
                vec4 srcColor = texture2D(inputImageTexture, uv);
                gl_FragColor = mix(srcColor, blackLineColor, blackLineColor.a);
            } else {
                gl_FragColor = texture2D(inputImageTexture, uv);
            }
        } else { // uv.x (1, 1.02}
            vec2 blackLineUv = vec2((uv.x - 1.0) / 0.02 * 0.3 + 0.35, uv.y);
            gl_FragColor = texture2D(inputImageTexture1, blackLineUv);
        }
    } else {
        if(uv.y < padding - 0.02) {
            vec2 srcUv = vec2(uv.x, uv.y + 1.0 - padding + 0.02);
            vec4 srcColor = texture2D(inputImageTexture, srcUv);
            if(uv.y > padding - 0.04) {
                vec2 blackLineUv = vec2(uv.x, (uv.y - padding + 0.04) / 0.02 * 0.35);
                vec4 blackLineColor = texture2D(inputImageTexture1, blackLineUv);
                srcColor = mix(srcColor, blackLineColor, blackLineColor.a);
                if(uv.y > padding - 0.04) {
                    vec2 yellowLineUv = vec2(uv.x, 1.0 - (uv.y - padding + 0.04) / 0.02);
                    vec4 yellowLineColor = texture2D(inputImageTexture2, yellowLineUv);
                    srcColor = hardlightBlend(srcColor,yellowLineColor);
                }
            }
            gl_FragColor = srcColor;
        } else if (uv.y > padding) {
            uv.y = uv.y - padding + 0.02;
            if(uv.y <= 0.04) {
                vec2 blackLineUv = vec2(uv.x, (uv.y - 0.02) / 0.02 * 0.35 + 0.65);
                vec4 blackLineColor = texture2D(inputImageTexture1, blackLineUv);
                vec4 srcColor = texture2D(inputImageTexture, uv);
                gl_FragColor = mix(srcColor, blackLineColor, blackLineColor.a);
            } else {
                gl_FragColor = texture2D(inputImageTexture, uv);
            }
        } else {
            vec2 blackLineUv = vec2(uv.x, (uv.y - padding + 0.02) / 0.02 * 0.3 + 0.35);
            gl_FragColor = texture2D(inputImageTexture1, blackLineUv);
        }
    }
}