precision highp float;
varying highp vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform highp float iTime;
uniform highp float effectValue;
uniform vec2 inputSize;


// wave frequency
#define FREQ 3.5

// noise iterations
#define DEPTH 1

float hash21(vec2 p) {
    p += vec2(3.2918, 9.29184);
    p *= fract(cos(p*3.29184)*10.29184);
    float MAX_HASH = 823785.0;
    float hx = mod(92.2918+p.x * MAX_HASH, MAX_HASH) / MAX_HASH;
    float hy = mod(92.2918+p.y * MAX_HASH, MAX_HASH) / MAX_HASH;
    vec2 p2 = vec2(hx, hy);
    return fract(10.92718 * cos(atan(hx, hy) * 9.291854) * dot(p, p2));
}

float noise(vec2 p) {
    vec2 id = floor(p);
    vec2 lv = smoothstep(0.0, 1.0, fract(p));
    float a = hash21(id);
    float b = hash21(id+vec2(1.0, 0.0));
    float ab = mix(a, b, lv.x);
    float c = hash21(id+vec2(0.0, 1.0));
    float d = hash21(id+vec2(1.0, 1.0));
    float cd = mix(c, d, lv.x);
    return mix(ab, cd, lv.y);
}

float perlin(vec2 p, float freq, int depth) {
    float n = 0.0;
    for (int i = 0; i < depth; i++) { n += noise(p*freq); freq *= 1.6;}
    return n / float(depth);
}

vec2 mirrorRepeat(vec2 v2) {
    vec2 uv = v2;
    uv += 1.0;
    uv *= 0.5;
    uv = fract(uv);
    uv = abs((uv-0.5) * 2.0);
    return uv;
}


void main() {
    vec2 uv = textureCoordinate;
    vec2 scale = inputSize.y > inputSize.x ? vec2(inputSize.x/inputSize.y,1.0): vec2(1.0,inputSize.y/inputSize.x);
    uv *= scale;

    float T  = ((iTime + 2.0)*0.25);
    vec4 col = vec4(0.0);
    float AMOUNT =  effectValue * 0.5;
    vec2 timeOffset = vec2(cos(T), sin(T));
    vec2 constantOffset = vec2(T*0.5, T*0.5) * (0.01*(0.5+(0.5*cos((T + 9.289178)*0.5))));

    uv.x *= -1.5;
    uv.y *= 0.5;
    
    float nx = perlin((textureCoordinate + timeOffset) + constantOffset, FREQ, DEPTH);
    float ny = perlin(constantOffset + (uv - timeOffset)+vec2(3.14281, 3.91892), FREQ, DEPTH);
    float nz = perlin(vec2(nx, ny)*timeOffset, FREQ, DEPTH);
    float nw = perlin(uv*nz, FREQ, DEPTH);
    vec2 offset = vec2(nx-nw, ny-nw)*nz;
    vec2 offsetUv = mix(textureCoordinate, textureCoordinate+offset, clamp(AMOUNT*max(0.16, nw), 0.0, 1.0));
    vec4 bg =texture2D(inputImageTexture, mirrorRepeat(offsetUv));
    col += bg;
    gl_FragColor = col;
}